@@ -1,5 +1,5 @@
 
-setClassUnion("character/NULL", c("character", "NULL"))
+# setClassUnion("character_NULL", c("character", "NULL"))
 
 #' @rdname dictionary-class
 #' @export
@@ -9,13 +9,11 @@ setClassUnion("character/NULL", c("character", "NULL"))
 #'   consisting of a pattern match
 #' @slot concatenator character object specifying space between multi-word
 #'   values
-#' @slot format dictionary format (if imported)
-#' @slot file file from which a dictionary was read (if imported)
-setClass("dictionary", contains = c("list"),
-         slots = c(concatenator = "character/NULL", format = "character/NULL", file = "character/NULL"),
-         prototype = prototype(concatenator = " ", format = NULL, file = NULL))
+setClass("dictionary2", contains = "list",
+         slots = c(concatenator = "character"),
+         prototype = prototype(concatenator = " "))
 
-setValidity("dictionary", function(object) {
+setValidity("dictionary2", function(object) {
     # does every element have a name? simply needs to pass
     validate_dictionary(object)
 })
@@ -24,12 +22,12 @@ setValidity("dictionary", function(object) {
 validate_dictionary <- function(dict){
     dict <- unclass(dict)
     if (is.null(names(dict))) {
-        stop("Dictionary elements must be named: ", 
+        stop("Dictionary elements must be named: ",
              paste(unlist(dict, recursive = TRUE), collapse = ' '))
     }
     if (any(names(dict) == "")) {
         unnamed <- dict[which(names(dict) == "")]
-        stop("Unnamed dictionary entry: ", 
+        stop("Unnamed dictionary entry: ",
              paste(unlist(unnamed, use.names = FALSE), collapse = ' '))
     }
     if (is.null(dict@concatenator) || dict@concatenator == '') {
@@ -79,7 +77,7 @@ print_dictionary <- function(entry, level = 1) {
 #' @param object the dictionary to be printed
 #' @rdname dictionary-class
 #' @export
-setMethod("show", "dictionary", 
+setMethod("show", "dictionary2", 
           function(object) {
               levs <- ifelse((depth <- dictionary_depth(object)) > 1, " primary", "")
               nkeys <- length(names(object))
@@ -96,9 +94,10 @@ setMethod("show", "dictionary",
 #' @rdname dictionary-class
 #' @export
 setMethod("[",
-          signature = c("dictionary", i = "index"),
+          signature = c("dictionary2", i = "index"),
           function(x, i) {
-              new("dictionary", unclass(x)[i], format = x@format, file = x@file, concatenator = x@concatenator)
+              is_category <- sapply(as.list(x)[i], function(y) !is.null(y))
+              dictionary(as.list(x)[i][is_category], concatenator = x@concatenator)
         })
 
 #' Extractor for dictionary objects
@@ -107,18 +106,28 @@ setMethod("[",
 #' @rdname dictionary-class
 #' @export
 setMethod("[[",
-          signature = c("dictionary", i = "index"),
+          signature = c("dictionary2", i = "index"),
           function(x, i) {
-              is_category <- sapply(unclass(x)[[i]], is.list)
-              new("dictionary", unclass(x)[[i]][is_category], format = x@format, file = x@file, concatenator = x@concatenator)
+              if (!is.list(as.list(x)[[i]])) {
+                  as.list(x)[[i]]
+              } else {
+                  dictionary(as.list(x)[[i]], concatenator = x@concatenator)
+              }
           })
 
+#' @rdname dictionary-class
+#' @param name the dictionary key
+#' @export
+`$.dictionary2` <- function(x, name) {
+    x[[name]]
+}
+
 #' Coerce a dictionary object into a list
 #' @param object the dictionary to be coerced
 #' @rdname dictionary-class
 #' @export
 setMethod("as.list",
-          signature = c("dictionary"),
+          signature = c("dictionary2"),
           function(x) {
               simplify_dictionary(x)
           })
@@ -166,6 +175,7 @@ setMethod("as.list",
 #'   Lexicoder format, \url{http://www.lexicoder.com}
 #'   
 #' @seealso \link{dfm}
+#' @import stringi
 #' @examples
 #' mycorpus <- corpus_subset(data_corpus_inaugural, Year>1900)
 #' mydict <- dictionary(list(christmas = c("Christmas", "Santa", "holiday"),
@@ -219,7 +229,7 @@ dictionary <- function(..., file = NULL, format = NULL,
         if (!file.exists(file))
             stop("File does not exist: ", file)
         if (is.null(format)) {
-            ext <- stringi::stri_trans_tolower(tools::file_ext(file))
+            ext <- stri_trans_tolower(tools::file_ext(file))
             if (ext %in% names(formats)) {
                 format <- formats[[ext]]
             } else {
@@ -232,7 +242,8 @@ dictionary <- function(..., file = NULL, format = NULL,
         if (format == "wordstat") {
             x <- read_dict_wordstat(file, encoding)
         } else if (format == "LIWC") {
-            x <- read_dict_liwc(file, encoding)
+            # x <- read_dict_liwc(file, encoding)
+            x <- list2dictionary(read_dict_liwc_old(file, encoding))
         } else if (format == "yoshikoder") {
             x <- read_dict_yoshikoder(file)
         } else if (format == "lexicoder") {
@@ -244,7 +255,7 @@ dictionary <- function(..., file = NULL, format = NULL,
     }
     if (tolower)
         x <- lowercase_dictionary(x)
-    new("dictionary", x, format = format, file = file, concatenator = concatenator)
+    new("dictionary2", x, concatenator = concatenator)
 }
 
 
@@ -322,7 +333,7 @@ lowercase_dictionary <- function(dict) {
             dict[[i]] <- lowercase_dictionary(dict[[i]])
         } else {
             if (is.character(dict[[i]])) {
-                dict[[i]] <- stringi::stri_trans_tolower(dict[[i]])
+                dict[[i]] <- stri_trans_tolower(dict[[i]])
             }
         }
     }
@@ -336,7 +347,7 @@ list2dictionary <- function(dict) {
             dict[[i]] = list2dictionary(dict[[i]])
         } else {
             if (is.character(dict[[i]])) {
-                dict[[i]] = list(stringi::stri_enc_toutf8(dict[[i]]))
+                dict[[i]] = list(stri_enc_toutf8(dict[[i]]))
             } else {
                 dict[[i]] = list(dict[[i]])
             }
@@ -352,7 +363,7 @@ list2dictionary <- function(dict) {
 #' @param x any object
 #' @export
 is.dictionary <- function(x) {
-    is(x, "dictionary")
+    is(x, "dictionary2")
 }
 
 
@@ -360,12 +371,12 @@ is.dictionary <- function(x) {
 # dict <- read_dict_lexicoder('/home/kohei/Documents/Dictionary/Lexicoder/LSDaug2015/LSD2015.lc3')
 read_dict_lexicoder <- function(path) {
     
-    lines <- stringi::stri_read_lines(path, encoding = 'utf-8') # Lexicoder 3.0 is always UTF-8
-    lines <- stringi::stri_trim_both(lines)
-    lines_yaml <- ifelse(stringi::stri_detect_regex(lines, '^\\+'),
-                         stringi::stri_replace_all_regex(lines, '^+(.+)$', '"$1":'),
-                         stringi::stri_replace_all_regex(lines, '^(.+)$', ' - "$1"'))
-    lines_yaml <- stringi::stri_replace_all_regex(lines_yaml, '[[:control:]]', '') # clean
+    lines <- stri_read_lines(path, encoding = 'utf-8') # Lexicoder 3.0 is always UTF-8
+    lines <- stri_trim_both(lines)
+    lines_yaml <- ifelse(stri_detect_regex(lines, '^\\+'),
+                         stri_replace_all_regex(lines, '^+(.+)$', '"$1":'),
+                         stri_replace_all_regex(lines, '^(.+)$', ' - "$1"'))
+    lines_yaml <- stri_replace_all_regex(lines_yaml, '[[:control:]]', '') # clean
     yaml <- paste0(lines_yaml, collapse = '\n')
     dict <- yaml::yaml.load(yaml, as.named.list = TRUE)
     dict <- list2dictionary(dict)
@@ -378,14 +389,14 @@ read_dict_lexicoder <- function(path) {
 # dict <- read_dict_wordstat('/home/kohei/Documents/Dictionary/Wordstat/WordStat Sentiments.cat', 'iso-8859-1')
 read_dict_wordstat <- function(path, encoding = 'auto') {
     
-    lines <- stringi::stri_read_lines(path, encoding = encoding, fallback_encoding = 'windows-1252')
-    lines <- stringi::stri_trim_right(lines)
-    lines_yaml <- ifelse(stringi::stri_detect_regex(lines, ' \\(\\d\\)$'),
-                         stringi::stri_replace_all_regex(lines, '^(\\t*)(.+) \\(\\d\\)$', '$1- "$2"'),
-                         stringi::stri_replace_all_regex(lines, '^(\\t*)(.+)$', '$1- "$2": '))
+    lines <- stri_read_lines(path, encoding = encoding, fallback_encoding = 'windows-1252')
+    lines <- stri_trim_right(lines)
+    lines_yaml <- ifelse(stri_detect_regex(lines, ' \\(\\d\\)$'),
+                         stri_replace_all_regex(lines, '^(\\t*)(.+) \\(\\d\\)$', '$1- "$2"'),
+                         stri_replace_all_regex(lines, '^(\\t*)(.+)$', '$1- "$2": '))
     
-    lines_yaml <- stringi::stri_replace_all_regex(lines_yaml, '\t', '  ') # needs two spaces
-    lines_yaml <- stringi::stri_replace_all_regex(lines_yaml, '[[:control:]]', '') # clean
+    lines_yaml <- stri_replace_all_regex(lines_yaml, '\t', '  ') # needs two spaces
+    lines_yaml <- stri_replace_all_regex(lines_yaml, '[[:control:]]', '') # clean
     yaml <- paste0(lines_yaml, collapse = '\n')
     dict <- yaml::yaml.load(yaml, as.named.list = TRUE)
     dict <- list2dictionary_wordstat(dict, FALSE)
@@ -416,26 +427,30 @@ list2dictionary_wordstat <- function(entry, omit = TRUE, dict = list()) {
 
 
 # Import a LIWC-formatted dictionary
-# read_dict_liwc('/home/kohei/Documents/Dictionary/LIWC/LIWC2007_English.dic')
+# read_dict_liwc('/home/kohei/Documents/Dictionary/LIWC/LIWC2007_English.dic')        # WORKS
+# dictionary(file = "~/Dropbox/QUANTESS/dictionaries/LIWC/LIWC2007_English.dic")      # WORKS
+# dictionary(file = "~/Dropbox/QUANTESS/dictionaries/LIWC/LIWC2015_English_Flat.dic") # WORKS
+# dictionary(file = "~/Dropbox/QUANTESS/dictionaries/LIWC/LIWC2001_English.dic")       # FAILS
+# dictionary(file = "~/Dropbox/QUANTESS/dictionaries/LIWC/LIWC2007_English080730.dic") # FAILS
 read_dict_liwc <- function(path, encoding = 'auto') {
     
-    lines <- stringi::stri_read_lines(path, encoding = encoding, fallback_encoding = 'windows-1252')
-    lines <- stringi::stri_trim_both(lines)
+    lines <- stri_read_lines(path, encoding = encoding, fallback_encoding = 'windows-1252')
+    lines <- stri_trim_both(lines)
     lines <- lines[lines != '']
     
     sections <- which(lines == '%')
     lines_key <- lines[(sections[1] + 1):(sections[2] - 1)]
     lines_value <- lines[(sections[2] + 1):(length(lines))]
     
-    keys <- stringi::stri_extract_last_regex(lines_key, '[^\t]+')
-    keys_id <- stringi::stri_extract_first_regex(lines_key, '\\d+')
+    keys <- stri_extract_last_regex(lines_key, '[^\t]+')
+    keys_id <- stri_extract_first_regex(lines_key, '\\d+')
     
-    values <- stringi::stri_extract_first_regex(lines_value, '[^\t]+')
-    lines_value <- stringi::stri_replace_first_regex(lines_value, '[^\t]+\t', '') # for safety
-    values_ids <- stringi::stri_extract_all_regex(lines_value, '\\d+')
+    values <- stri_extract_first_regex(lines_value, '[^\t]+')
+    lines_value <- stri_replace_first_regex(lines_value, '[^\t]+\t', '') # for safety
+    values_ids <- stri_extract_all_regex(lines_value, '\\d+')
     
-    keys <- stringi::stri_replace_all_regex(keys, '[[:control:]]', '') # clean
-    values <- stringi::stri_replace_all_regex(values, '[[:control:]]', '') # clean
+    keys <- stri_replace_all_regex(keys, '[[:control:]]', '') # clean
+    values <- stri_replace_all_regex(values, '[[:control:]]', '') # clean
     
     dict <- split(rep(values, lengths(values_ids)), as.factor(unlist(values_ids, use.names = FALSE)))
     dict <- dict[order(as.numeric(names(dict)))]
@@ -450,7 +465,7 @@ read_dict_liwc <- function(path, encoding = 'auto') {
 read_dict_yoshikoder <- function(path){
     
     xml <- XML::xmlParse(path)
-    root <- XML::xpathSApply(xml, "/dictionary")
+    root <- XML::xpathSApply(xml, "/dictionary/cnode")
     dict <- nodes2list(root[[1]])
     dict <- list2dictionary(dict)
     return(dict)
@@ -458,10 +473,10 @@ read_dict_yoshikoder <- function(path){
 
 # Internal function for read_dict_yoshikoder
 nodes2list <- function(node, dict = list()){
-    nodes <- XML::xpathSApply(node, "cnode/cnode")
+    nodes <- XML::xpathSApply(node, "cnode")
     if (length(nodes)) {
         for (i in seq_along(nodes)) {
-            key <- XML::xmlGetAttr(nodes[[i]], name="name")
+            key <- XML::xmlGetAttr(nodes[[i]], name = "name")
             dict[[key]] <- nodes2list(nodes[[i]], dict[[key]])
         }
     } else {
@@ -487,7 +502,7 @@ nodes2list <- function(node, dict = list()){
 #' }
 as.yaml <- function(x) {
     yaml <- yaml::as.yaml(simplify_dictionary(x, TRUE), indent.mapping.sequence = TRUE)
-    yaml <- stringi::stri_enc_toutf8(yaml)
+    yaml <- stri_enc_toutf8(yaml)
     return(yaml)
 }
 
