@@ -56,7 +56,7 @@ syllables <- function(x, ...) {
 #' # tokens
 #' txt <- c(doc1 = "This is an example sentence.",
 #'          doc2 = "Another of two sample sentences.")
-#' nsyllable(tokens(txt, removePunct = TRUE))
+#' nsyllable(tokens(txt, remove_punct = TRUE))
 #' # punctuation is not counted
 #' nsyllable(tokens(txt), use.names = TRUE)
 nsyllable <- function(x, syllable_dictionary = quanteda::data_int_syllables, use.names = FALSE) {
@@ -111,9 +111,9 @@ nsyllable.tokens <- function(x, syllable_dictionary = quanteda::data_int_syllabl
 nsyllable.tokenizedTexts <- function(x, syllable_dictionary = quanteda::data_int_syllables, use.names = FALSE) { 
     
     # make tokenized list into a data table
-    syllablesDT <- data.table(docIndex = rep(1:length(x), lengths(x)),
+    syllablesDT <- data.table(docIndex = rep(seq_along(x), lengths(x)),
                               word = unlist(x), 
-                              serial = 1:length(unlist(x)))
+                              serial = seq_along(unlist(x)))
     
     # call the syllables data.table function
     nSyllables <- nsyllable.data.table(syllablesDT, syllable_dictionary)    
