@@ -21,7 +21,7 @@ test_that("compare the output feature co-occurrence matrix to that of the text2v
     tcm <- tcm[order(rownames(tcm)), order(colnames(tcm))]
     tcm[lower.tri(tcm,diag = FALSE)] <- 0
     
-    toks <- tokenize(char_tolower(txt), removePunct = TRUE)
+    toks <- tokenize(char_tolower(txt), remove_punct = TRUE)
     fcm <- fcm(toks, context = "window", count = "weighted", window = 3)
     fcm <- fcm_sort(fcm)
     diag(fcm) <- 0
@@ -242,7 +242,7 @@ test_that("window = 3",{
 test_that("fcm.dfm works same as fcm.tokens", {
     txt <- c("The quick brown fox jumped over the lazy dog.",
              "The dog jumped and ate the fox.")
-    toks <- tokens(char_tolower(txt), removePunct = TRUE)
+    toks <- tokens(char_tolower(txt), remove_punct = TRUE)
     expect_equal(fcm(toks, context = "document"),
                  fcm(dfm(toks), context = "document"))
 })
@@ -250,17 +250,25 @@ test_that("fcm.dfm works same as fcm.tokens", {
 test_that("fcm.dfm only works for context = \"document\"", {
     txt <- c("The quick brown fox jumped over the lazy dog.",
              "The dog jumped and ate the fox.")
-    toks <- tokens(char_tolower(txt), removePunct = TRUE)
+    toks <- tokens(char_tolower(txt), remove_punct = TRUE)
     expect_error(fcm(dfm(toks), context = "window"),
                  "fcm.dfm only works on context = \"document\"")
 })
 
+test_that("fcm.dfm does works for context = \"document\" with weighed counts", {
+    txt <- c("The quick brown fox jumped over the lazy dog.",
+             "The dog jumped and ate the fox.")
+    toks <- tokens(char_tolower(txt), remove_punct = TRUE)
+    expect_error(fcm(dfm(toks), context = "document", count = "weighted"),
+                 "Cannot have weighted counts with context = \"document\"")
+})
+
 test_that("fcm works as expected for tokens_hashed", {
     
     txt <- c("The quick brown fox jumped over the lazy dog.",
              "The dog jumped and ate the fox.")
-    toks <- tokenize(char_tolower(txt), removePunct = TRUE)
-    toksh <- tokens(char_tolower(txt), removePunct = TRUE)
+    toks <- tokenize(char_tolower(txt), remove_punct = TRUE)
+    toksh <- tokens(char_tolower(txt), remove_punct = TRUE)
     classic <- fcm(toks, context = "window", window = 3)
     hashed <- fcm(toksh, context = "window", window = 3)
     expect_equivalent(classic, hashed)
@@ -273,6 +281,10 @@ test_that("fcm print works as expected", {
                   "^Feature co-occurrence matrix of: 6 by 6 features.")
     expect_output(print(testfcm[1:5, 1:5]),
                   "^Feature co-occurrence matrix of: 5 by 5 features.")
+    expect_output(print(testfcm, show.settings=T),
+                  "Settings: TO BE IMPLEMENTED")
+    expect_output(show(testfcm),
+                  "^Feature co-occurrence matrix of: 6 by 6 features.")
 })
 
 test_that("fcm works the same for different object types", {
@@ -282,3 +294,8 @@ test_that("fcm works the same for different object types", {
     expect_identical(fcm(txts), fcm(tokens(txts)))
 })
 
+test_that("fcm expects warning for a wrong weights length", {
+    xts <- c("a a a b b c", "a a c e", "a c e f g")
+    expect_warning(fcm(tokens(xts), context = "window", window = 2, count = "weighted", weights = c(1,2,3)),
+                 "weights length is not equal to the window size, weights are assigned by default!")
+})
