@@ -306,7 +306,7 @@ test_that("textstat_simil stops as expected for methods not supported",{
     presDfm <- dfm(corpus_subset(data_corpus_inaugural, Year > 1980), remove = stopwords("english"),
                    stem = TRUE, verbose = FALSE)
     expect_error(textstat_simil(presDfm, method = "Yule"), 
-                 "The metric is not currently supported by quanteda, please use other packages such as proxy::dist\\(\\)\\/simil\\(\\).")
+    "Yule is not implemented; consider trying proxy::simil\\(\\)")
 })
 
 test_that("textstat_simil stops as expected for wrong selections",{
@@ -322,15 +322,15 @@ test_that("textstat_simil stops as expected for wrong selections",{
     
 })
 
-test_that("test textstat_simil works as expected for 'n' is not NULL", {
-    skip_if_not_installed("proxy")
-    presDfm <- dfm(corpus_subset(data_corpus_inaugural, Year > 1980), remove = stopwords("english"),
-                   stem = TRUE, verbose = FALSE)
-    
-    cosQuanteda <- round(as.matrix(suppressWarnings(textstat_simil(presDfm, method = "cosine", n=5, margin = "documents")))[,"1981-Reagan"], 6)
-    cosProxy <- round(as.matrix(proxy::simil(as.matrix(presDfm), "cosine", by_rows = TRUE, diag = TRUE))[, "1981-Reagan"], 6)
-    expect_equal(cosQuanteda, cosProxy[1:5])
-})
+# test_that("test textstat_simil works as expected for 'n' is not NULL", {
+#     skip_if_not_installed("proxy")
+#     presDfm <- dfm(corpus_subset(data_corpus_inaugural, Year > 1980), remove = stopwords("english"),
+#                    stem = TRUE, verbose = FALSE)
+#     
+#     cosQuanteda <- round(as.matrix(suppressWarnings(textstat_simil(presDfm, method = "cosine", margin = "documents")))[,"1981-Reagan"], 6)
+#     cosProxy <- round(as.matrix(proxy::simil(as.matrix(presDfm), "cosine", by_rows = TRUE, diag = TRUE))[, "1981-Reagan"], 6)
+#     expect_equal(cosQuanteda, cosProxy[1:5])
+# })
 
 # test_that("as.dist on a dist returns a dist", {
 #     presDfm <- dfm(corpus_subset(data_corpus_inaugural, Year > 1990), remove = stopwords("english"),
