@@ -82,56 +82,3 @@ test_that("features2vector works as expected", {
 
 
 
-test_that("deprecate_arguments works as expected", {
-    fn <- function(remove_numbers = TRUE, ...) {
-        args <- as.list(match.call())
-        remove_numbers <- quanteda:::deprecate_argument("removeNumbers", "remove_numbers", args)
-        cat("remove_numbers =", remove_numbers, "\n")
-    }
-    expect_warning(
-        fn(removeNumbers = FALSE),
-        "argument \"removeNumbers\" is deprecated: use \"remove_numbers\" instead."
-    )
-    expect_output(
-        fn(remove_numbers = FALSE),
-        "remove_numbers = FALSE"
-    )
-    
-    # for tokens
-    expect_identical(
-        as.character(tokens(c(d1 = "This: punctuation"), remove_punct = TRUE)),
-        c("This", "punctuation")
-    )
-    expect_identical(
-        as.character(tokens(c(d1 = "This: punctuation"), remove_punct = TRUE)),
-        as.character(tokens(c(d1 = "This: punctuation"), remove_punct = TRUE))
-    )
-    expect_warning(
-        as.character(tokens(c(d1 = "This: punctuation"), removePunct = TRUE)),
-        "argument \"removePunct\" is deprecated: use \"remove_punct\" instead."
-    )    
-    expect_warning(
-        tokens(c(d1 = "This: punctuation"), notanargument = TRUE),
-        "Argument notanargument not used"
-    )
-    
-})
-
-test_that("deprecate arguments works with values from parent frame", {
-    fn <- function(remove_numbers = TRUE, ...) {
-        args <- as.list(match.call())
-        args <- lapply(args, function(a) eval(a, enclos = parent.frame()))
-        remove_numbers <- quanteda:::deprecate_argument("removeNumbers", "remove_numbers", args)
-        cat("remove_numbers =", remove_numbers, "\n")
-    }
-    tmp = FALSE
-    
-    expect_output(
-        fn(remove_numbers = tmp),
-        "remove_numbers = FALSE"
-    )
-    expect_output(
-        fn(removeNumbers = tmp),
-        "remove_numbers = FALSE"
-    )
-})
